@@ -164,6 +164,8 @@ from bitmovin_api_sdk.models.billable_encoding_minutes_details import BillableEn
 from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
 from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
 from bitmovin_api_sdk.models.bitmovin_response_list import BitmovinResponseList
+from bitmovin_api_sdk.models.bitmovin_stream_encoding_status import BitmovinStreamEncodingStatus
+from bitmovin_api_sdk.models.bitmovin_stream_encoding_task import BitmovinStreamEncodingTask
 from bitmovin_api_sdk.models.bitmovin_stream_quality import BitmovinStreamQuality
 from bitmovin_api_sdk.models.bitmovin_stream_response import BitmovinStreamResponse
 from bitmovin_api_sdk.models.bitmovin_stream_status import BitmovinStreamStatus
